@@ -185,11 +185,10 @@ class ROCv3():
 
     def _translate(self, valid_config: dict,
                    translation_dictionary=None,
-                   translation_output_registers=[],
-                   transaction_log_written=False) -> list:
+                   first_call=True) -> list:
         # do this to avoid weird referencing and static variable behaviour
-        translation_output_registers = translation_output_registers.copy()
-        if not transaction_log_written:
+        output_regs = []
+        if first_call:
             self.transaction_logger.debug(
                 "Translating configuration dictionary")
 
@@ -197,11 +196,10 @@ class ROCv3():
             translation_dictionary = self.translation_dict
         for key, val in valid_config.items():
             if isinstance(val, dict):
-                translation_output_registers += self._translate(
-                        val,
-                        translation_dictionary[key],
-                        translation_output_registers,
-                        transaction_log_written=True)
+                output_regs += self._translate(
+                                  val,
+                                  translation_dictionary[key],
+                                  first_call=False)
             else:
                 param_registers = translation_dictionary[key].keys()
                 masks = translation_dictionary[key].values()
@@ -209,9 +207,9 @@ class ROCv3():
                     aligned_val = \
                         ((val & m['param_mask']) >> m['param_minbit'])\
                         << m['reg_minbit']
-                    translation_output_registers.append(
+                    output_regs.append(
                             (r[0], r[1], aligned_val, m['reg_mask']))
-        return translation_output_registers
+        return output_regs
 
     def _translate_read(self, valid_config, translation_dictionary=None,
                         curr_key=[], param_reg_pairs=[],
@@ -276,8 +274,7 @@ class ROCv3():
             raise KeyError(str(err.args[0]) + f" in ROC {self.name}")
         except ValueError as err:
             raise ValueError(str(err.args[0]) + f" in ROC {self.name}")
-        register_updates = self._translate(configuration,
-                                           translation_output_registers=[])
+        register_updates = self._translate(configuration)
         register_writes = self._cache(register_updates)
         self.transaction_logger.info("Updating configuration in "
                                      f'{len(register_writes)} registers')
