@@ -101,20 +101,27 @@ def test_validator(config, result, patched_io):
 
 
 @pytest.mark.parametrize(
-        "config, registers",
+        "first_config, first_output, second_config, second_output",
         [
             ({
               'DigitalHalf': {1: {'IdleFrame': 200}}
               },
              [(112, 5, 200, 255), (113, 5, 0, 255),
+              (114, 5, 0, 255), (115, 5, 0, 15)],
+             {
+             'DigitalHalf': {1: {'IdleFrame': 100}}
+             },
+             [(112, 5, 100, 255), (113, 5, 0, 255),
               (114, 5, 0, 255), (115, 5, 0, 15)]
              )
         ])
-def test_translator(config, registers, patched_io):
+def test_translator(first_config, first_output, second_config,
+                    second_output, patched_io):
     roc_s0 = ROCv3(name='roc_s0', transport=None, base_address=None,
                    reset_pin=hexactrl_io.Xil_gpio('that', 'rst', 'output'),
                    path_to_file='regmaps/HGCROC3_I2C_params_regmap.csv')
-    assert roc_s0._translate(config) == registers
+    assert roc_s0._translate(first_config) == first_output
+    assert roc_s0._translate(second_config) == second_output
 
 
 @pytest.mark.parametrize(
